@echo off
::
:: Copyright (c) 2014-2024 Linagora
::
:: This program/library is free software: you can redistribute it and/or modify
:: it under the terms of the GNU Lesser General Public License as published by
:: the Free Software Foundation, either version 2.1 of the License, or (at your
:: option) any later version.
::
:: This program/library is distributed in the hope that it will be useful, but
:: WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
:: FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
:: for more details.
::
:: You should have received a copy of the GNU Lesser General Public License
:: along with this program/library; If not, see http://www.gnu.org/licenses/
:: for the GNU Lesser General Public License version 2.1.
::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::
::                   Petals Registry CLI bootstrap script
::
:: Environment variables:
::
::     JAVA_HOME   Home directory of the JVM to be used
::
::     JAVA_OPTS   Options for the JVM. Try "java -h" to get informations
::                 about the available options for your environment
::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::


:: Set the path to the java executable
if not defined JAVA_HOME (
   set JAVA=java
) else (
   set JAVA="%JAVA_HOME%\bin\java.exe"
)

:: Set the path to bootstrap jar
set PETALS_REGISTRY_CLI_JAR="%CD%\..\lib\petals-registry-cli.jar"
if not exist %PETALS_REGISTRY_CLI_JAR% (
	echo ERROR: petals-registry-cli.jar: the jar archive was not found
	goto :EOF
)

:: Get the content of variables at runtime and not at parse time
:: %var% = parse time
:: !var! = run time
setlocal EnableDelayedExpansion

:: Add installed Petals CLI extensions to the classpath
set PETALS_REGISTRY_CLI_CLASSPATH=%PETALS_REGISTRY_CLI_JAR%
for %%a in ("%CD%\..\extensions\*.jar") do (
	set PETALS_REGISTRY_CLI_CLASSPATH=!PETALS_REGISTRY_CLI_CLASSPATH!;"%%a"
)

:: Add default preferences file to the classpath
set PETALS_REGISTRY_CLI_CLASSPATH=%PETALS_REGISTRY_CLI_CLASSPATH%;"%CD%\..\conf"

:: Set a possible user preference file
set USER_PREFS="%HOMEPATH%\.petals-cli\petals-registry-cli.default"
if exist %USER_PREFS% (
   :: A user preference file exists, use it.
   set PETALS_REGISTRY_CLI_PREFS=%USER_PREFS%
)

:: Start
%JAVA% -classpath %PETALS_REGISTRY_CLI_CLASSPATH% %JAVA_OPTS% -Djline.shutdownhook=true org.ow2.petals.registry.cli.Main %*
